<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
  <xsl:output method="xml" indent="yes" doctype-system="DTD/utility-model-specification.dtd"  encoding="UTF-8"/>
  <xsl:param name="pXml1"/>
  <xsl:param name="pXml2"/>
  <xsl:param name="pXml3"/>
  <xsl:param name="pXml4"/>
  <xsl:param name="pRoot"/>
  <xsl:template match="/">
    <xsl:variable name="vXml1" select="$pXml1"/>
    <xsl:variable name="vXml2" select="$pXml2"/>
    <xsl:variable name="vXml3" select="$pXml3"/>
    <xsl:variable name="vXml4" select="$pXml4"/>
    <xsl:element name="utility-model-specification">
      <xsl:attribute name="receive-num"/>
      <xsl:attribute name="receive-date"/>
      <xsl:attribute name="dtd-version">2.0.1</xsl:attribute>
      <xsl:attribute name="application-num"/>
      <xsl:attribute name="status">n</xsl:attribute>
      <xsl:attribute name="produced-by">applicant</xsl:attribute>
      
      <!--<xsl:apply-templates select="$vXml1/utility-model-specification-abstract"/>-->

      <abstract lang="tw">
        <abstract-dtext>
          <p general="">
            <xsl:apply-templates select="$vXml1/utility-model-specification-abstract/tw-abstract-dtext"/>
          </p>
        </abstract-dtext>
      </abstract>

      <abstract lang="en">
        <abstract-dtext>
          <p general="">
            <xsl:apply-templates select="$vXml1/utility-model-specification-abstract/en-abstract-dtext"/>
          </p>
        </abstract-dtext>
      </abstract>
      
      
      <description>
        <xsl:apply-templates select="$vXml1/utility-model-specification-abstract/tw-utility-model-title"/>
        <xsl:apply-templates select="$vXml1/utility-model-specification-abstract/en-utility-model-title"/>
        <technical-field>
          <xsl:apply-templates select="$vXml2/utility-model-specification-description/technical-field/p"/>
        </technical-field>
        <background-art>
          <xsl:apply-templates select="$vXml2/utility-model-specification-description/background-art/p"/>
        </background-art>
        <disclosure>
          <xsl:apply-templates select="$vXml2/utility-model-specification-description/disclosure/p"/>
        </disclosure>
        <mode-for-invention>
          <xsl:apply-templates select="$vXml2/utility-model-specification-description/mode-for-invention/p"/>
        </mode-for-invention>
        <description-of-drawings>
          <description-of-element>
            <xsl:apply-templates select="$vXml2/utility-model-specification-description/description-of-element/p"/>
          </description-of-element>
          <xsl:apply-templates select="$vXml2/utility-model-specification-description/description-of-drawings/p"/>
        </description-of-drawings>
      </description>
      <claims>
        <xsl:apply-templates select="$vXml3/utility-model-specification-claims/claim"/>
        <xsl:apply-templates select="$vXml3/utility-model-specification-claims/claim01"/>
      </claims>
      <xsl:apply-templates select="$vXml1/utility-model-specification-abstract/general-chemistry"/>
      <xsl:apply-templates select="$vXml1/utility-model-specification-abstract/figure-drawings"/>
      <xsl:apply-templates select="$vXml4/utility-model-specification-drawings"/>
    </xsl:element>
  </xsl:template>
  <xsl:template match="utility-model-specification-abstract">
    <xsl:element name="abstract">
      <xsl:attribute name="lang">tw</xsl:attribute>
      <abstract-dtext>
        <p general="">
          <xsl:value-of select="tw-abstract-dtext"/>
        </p>
      </abstract-dtext>
    </xsl:element>
    <xsl:element name="abstract">
      <xsl:attribute name="lang">en</xsl:attribute>
      <abstract-dtext>
        <p general="">
          <xsl:value-of select="en-abstract-dtext"/>
        </p>
      </abstract-dtext>
    </xsl:element>
  </xsl:template>
  <xsl:template match="tw-utility-model-title">
    <utility-model-title lang="tw">
      <xsl:value-of select="."/>
    </utility-model-title>
  </xsl:template>
  <xsl:template match="en-utility-model-title">
    <utility-model-title lang="en">
      <xsl:value-of select="."/>
    </utility-model-title>
  </xsl:template>
  <xsl:template match="p">
    <p>
      <xsl:attribute name="general">
        <xsl:value-of select="@general"/>
      </xsl:attribute>
      <xsl:apply-templates select="*|text()"/>
    </p>
  </xsl:template>

  <xsl:template match="claim">
    <claim>
      <xsl:attribute name="dependency">independent-claim</xsl:attribute>
      <xsl:attribute name="num">
        <xsl:number value="position()" format="1"/>
      </xsl:attribute>
      <claim-text>
        <xsl:apply-templates select="*|text()"/>
      </claim-text>
    </claim>
  </xsl:template>
  <xsl:template match="claim01">
    <claim>
      <xsl:attribute name="dependency">independent-claim</xsl:attribute>
      <xsl:attribute name="num">
        <xsl:number value="position()" format="1"/>
      </xsl:attribute>
      <claim-text>
        <xsl:apply-templates select="*|text()"/>
      </claim-text>
    </claim>
  </xsl:template>
  <xsl:template match="general-chemistry">
    <xsl:element name="general-chemistry">
      <xsl:attribute name="num">
        <xsl:number value="position()" format="1"/>
      </xsl:attribute>
      <xsl:apply-templates select="img"/>
      <xsl:apply-templates select="p"/>
    </xsl:element>
  </xsl:template>
  <xsl:template match="figure-drawings">
    <xsl:element name="figure-drawings">
      <xsl:attribute name="lang"/>
      <xsl:attribute name="figure-labels">
        <xsl:value-of select="../figure-labels" />
      </xsl:attribute>
      
      <!--
      <p general="">
        <xsl:value-of select="."/>
      </p>
      -->

      <p general="">
        <xsl:apply-templates select="*|text()"/>
      </p>
      
    </xsl:element>
  </xsl:template>
  <xsl:template match="utility-model-specification-drawings">
    <xsl:element name="drawings">
      <xsl:attribute name="lang"/>
      <xsl:apply-templates select="figure"/>
    </xsl:element>
  </xsl:template>
  <xsl:template match="figure">
    <xsl:element name="figure">
      <xsl:attribute name="figure-labels">
        <xsl:value-of select="@figure-labels"/>
      </xsl:attribute>
      <xsl:apply-templates select="img"/>
    </xsl:element>
  </xsl:template>
  <xsl:template match="img">
    <xsl:element name="img">
      <xsl:attribute name="he">
        <xsl:value-of select="@he"/>
      </xsl:attribute>
      <xsl:attribute name="wi">
        <xsl:value-of select="@wi"/>
      </xsl:attribute>
      <xsl:attribute name="file">
        <xsl:value-of select="@file"/>
      </xsl:attribute>
      <xsl:attribute name="img-format">
        <xsl:value-of select="@img-format"/>
      </xsl:attribute>
      <xsl:attribute name="id">
        <xsl:text>i</xsl:text>
        <xsl:number value="count(../preceding-sibling::*) + 1" format="0001"/>
      </xsl:attribute>
    </xsl:element>
  </xsl:template>
  <xsl:template match="br">
    <xsl:apply-templates select="*|text()"/>
    <br/>
  </xsl:template>
  <xsl:template match="i">
    <i>
      <xsl:apply-templates select="*|text()"/>
    </i>
  </xsl:template>
  <xsl:template match="u">
    <u>
      <xsl:apply-templates select="*|text()"/>
    </u>
  </xsl:template>
  <xsl:template match="b">
    <b>
      <xsl:apply-templates select="*|text()"/>
    </b>
  </xsl:template>
  <xsl:template match="s">
    <s>
      <xsl:apply-templates select="*|text()"/>
    </s>
  </xsl:template>
  <xsl:template match="sup">
    <sup>
      <xsl:apply-templates select="*|text()"/>
    </sup>
  </xsl:template>
  <xsl:template match="sub">
    <sub>
      <xsl:apply-templates select="*|text()"/>
    </sub>
  </xsl:template>
  <xsl:template match="tables">
    <tables>
      <xsl:attribute name="num"/>
      <xsl:apply-templates select="*|text()"/>
    </tables>
  </xsl:template>
  <xsl:template match="table|tr">
    <xsl:copy>
      <xsl:apply-templates select="node()"/>
    </xsl:copy>
  </xsl:template>
  <xsl:template match="td">
    <xsl:copy-of select="." />
  </xsl:template>
</xsl:stylesheet>
