<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
  <xsl:output method="xml" indent="yes" doctype-system="DTD/patent-simple-A.dtd" encoding="UTF-8"/>
  <xsl:template match="/patent-simple-A-third-party-opinion">
    <patent-simple-A receive-num="" receive-date="" dtd-version="2.0.1" application-version="1.0.7" form-version="1.0.6" fee-version="1.0.2" application-num="" status="a" produced-by="submitter" form-type="n">
      <xsl:attribute name="application-num">
        <xsl:value-of select="application-num"/>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="type-of-patent='發明'">
          <xsl:attribute name="type-of-patent">invention</xsl:attribute>
        </xsl:when>
        <xsl:when test="type-of-patent='新型'">
          <xsl:attribute name="type-of-patent">utility</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="type-of-patent">design</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <xsl:choose>
        <xsl:when test="count(recognizance9)&gt;0">
          <xsl:attribute name="recognizance9">
            <xsl:text>y</xsl:text>
          </xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="recognizance9">
            <xsl:text>n</xsl:text>
          </xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <xsl:choose>
        <xsl:when test="count(recognizance10)&gt;0">
          <xsl:attribute name="recognizance10">
            <xsl:text>y</xsl:text>
          </xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="recognizance10">
            <xsl:text>n</xsl:text>
          </xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <xsl:choose>
        <xsl:when test="count(recognizance11)&gt;0">
          <xsl:attribute name="recognizance11">
            <xsl:text>y</xsl:text>
          </xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="recognizance11">
            <xsl:text>n</xsl:text>
          </xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <xsl:choose>
        <xsl:when test="count(recognizance12)&gt;0">
          <xsl:attribute name="recognizance12">
            <xsl:text>y</xsl:text>
          </xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="recognizance12">
            <xsl:text>n</xsl:text>
          </xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <xsl:choose>
        <xsl:when test="check-list/contact='未變更本案基本資料'">
          <xsl:attribute name="with-contact">
            <xsl:text>n</xsl:text>
          </xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="with-contact">
            <xsl:text>y</xsl:text>
          </xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      
      <xsl:apply-templates select="basis"/>
      <xsl:copy-of select="case-code"/>
      <file-reference-id>
        <xsl:value-of select="file-reference-id"/>
      </file-reference-id>

      <xsl:if test="count(submitter-secret-public-item)&gt;0">
        <original-data>
          <originalType>專簡A-發明專利申請案第三方意見書</originalType>
        </original-data>
      </xsl:if>
      
      <xsl:apply-templates select="patent-title-tw"/>

      <xsl:apply-templates select="parties"/>

      <xsl:apply-templates select="application-content"/>

      <xsl:apply-templates select="secret-public-item"/>

      <xsl:apply-templates select="submitter-secret-public-item"/>

      <xsl:apply-templates select="substantive-date"/>
      
      
      <priority-claims>
        <xsl:apply-templates select="priority-claim"/>
      </priority-claims>

      <fee-year>
        <start-year>
          <xsl:value-of select="fee-year/start-year"/>
        </start-year>
        <finish-year>
          <xsl:value-of select="fee-year/finish-year"/>
        </finish-year>
      </fee-year>

      <reduce-receipt>
        <reduction-annual>
          <xsl:value-of select="reduce-receipt/reduction-annual"/>
        </reduction-annual>
        <reason>
          <xsl:value-of select="reduce-receipt/reason"/>
        </reason>
      </reduce-receipt>

      <apply-recover>
        <xsl:value-of select="apply-recover"/>
      </apply-recover>

      <check-list>
        <xsl:apply-templates select="check-list"/>
      </check-list>

      <fee-sheet lang="" file="" ro="">
        <applicant-name>
          <name>
            <xsl:value-of select="fee-sheet/fee-name"/>
          </name>
          <iid>
            <xsl:value-of select="deposit-account/iid"/>
          </iid>
          <registered-number/>

        </applicant-name>
        <prescribed-fees currency=""/>
        <deposit-account>
          <authorization/>
          <ro>
            <country/>
          </ro>
          <account-no>
            <xsl:value-of select="deposit-account/account-no"/>
          </account-no>
          <receipt-type>
            <xsl:value-of select="deposit-account/receipt-type"/>
          </receipt-type>
          <date/>
          <name/>
          <registered-number/>
        </deposit-account>

        <dtext>
          <xsl:value-of select="fee-sheet/fee-dtext"/>
        </dtext>
      </fee-sheet>
      <xsl:apply-templates select="specification-item"/>

    </patent-simple-A>
  </xsl:template>

  <xsl:template match="patent-title-tw">
    <invention-title lang="tw">
      <xsl:value-of select="."/>
    </invention-title>
  </xsl:template>

  <xsl:template match="parties">
    <parties>
      <submitters>
        <xsl:apply-templates select="submitter"/>
      </submitters>
      <xsl:apply-templates select="correspondence-address"/>
      <agents>
        <xsl:apply-templates select="agent"/>
      </agents>
    </parties>
  </xsl:template>

  <xsl:template match="secret-public-item">
    <xsl:element name="secret-public-item">
      <xsl:element name="simpleap-name-address">
        <xsl:value-of select="simpleap-name-address"/>
      </xsl:element>
      <xsl:element name="simpleap-ref">
        <xsl:value-of select="simpleap-ref"/>
      </xsl:element>
    </xsl:element>
  </xsl:template>

  <xsl:template match="submitter-secret-public-item">
    <xsl:element name="submitter-secret-public-item">
      <xsl:apply-templates select="*|text()"/>
    </xsl:element>
  </xsl:template>
  
  <xsl:template match="application-content">
    <xsl:element name="application-content">
      <xsl:apply-templates select="*|text()"/>
    </xsl:element>
  </xsl:template>

  <xsl:template match="substantive-date">
    <xsl:element name="substantive-date">
      <xsl:apply-templates select="*|text()"/>
    </xsl:element>
  </xsl:template>
  
  
  <xsl:template match="submitter">
    <submitter>
      <xsl:attribute name="sequence">
        <xsl:number value="position()" format="1"/>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="sub-designated-receiver='是'">
          <xsl:attribute name="designated-receiver">
            <xsl:value-of  select="translate(sub-designated-receiver,'是','y')"/>
          </xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="designated-receiver">
            <xsl:text>n</xsl:text>
          </xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <addressbook lang="tw">
        <xsl:choose>
          <xsl:when test="sub-name-type='自然人'">
            <last-name>
              <xsl:value-of select="normalize-space(substring-before(sub-tw-name,','))"/>
            </last-name>
            <first-name>
              <xsl:value-of select="normalize-space(substring-after(sub-tw-name,','))"/>
            </first-name>
          </xsl:when>
          <xsl:otherwise>
            <orgname>
              <xsl:value-of select="normalize-space(sub-tw-comname)"/>
            </orgname>
          </xsl:otherwise>
        </xsl:choose>
        <role>
          <xsl:value-of select="sub-name-type"/>
        </role>
        <iid>
          <xsl:value-of select="sub-tw-iid"/>
        </iid>
        <registered-number/>
        <representative>
          <xsl:value-of select="sub-tw-representative"/>
        </representative>
        <address lang="tw">
          <zip-code>
            <xsl:value-of select="sub-zip-code"/>
          </zip-code>
          <dtext>
            <xsl:value-of select="sub-tw-address"/>
          </dtext>
        </address>
        <phones>
          <phone-region/>
          <phone>
            <xsl:value-of select="sub-tw-phone"/>
          </phone>
        </phones>
        <fax>
          <xsl:value-of select="sub-tw-fax"/>
        </fax>
        <cell-phone>
          <xsl:value-of select="sub-tw-cell-phone"/>
        </cell-phone>
        <email>
          <xsl:value-of select="sub-tw-email"/>
        </email>
      </addressbook>
      <addressbook lang="en">
        <xsl:choose>
          <xsl:when test="sub-name-type='自然人'">
            <last-name>
              <xsl:value-of select="normalize-space(substring-before(sub-en-name,','))"/>
            </last-name>
            <first-name>
              <xsl:value-of select="normalize-space(substring-after(sub-en-name,','))"/>
            </first-name>
          </xsl:when>
          <xsl:otherwise>
            <orgname>
              <xsl:value-of select="normalize-space(sub-en-comname)"/>
            </orgname>
          </xsl:otherwise>
        </xsl:choose>
        <iid>
          <xsl:value-of select="sub-tw-iid"/>
        </iid>
        <registered-number/>
        <representative>
          <xsl:value-of select="suben-representative"/>
        </representative>
        <address lang="en">
          <dtext>
            <xsl:value-of select="sub-en-address"/>
          </dtext>
        </address>
        <email/>
      </addressbook>
      <nationality>
        <country>
          <xsl:value-of select="substring(sub-country,'3')"/>
        </country>
        <country-code>
          <xsl:value-of select="substring(sub-country,'1','2')"/>
        </country-code>
      </nationality>
      <residence>
        <country>
          <xsl:value-of select="sub-living-country"/>
        </country>
      </residence>
      <legal-representative lang="tw">
        <addressbook lang="tw">
          <last-name>
            <xsl:value-of select="normalize-space(substring-before(ap-tw-legal-name,','))"/>
          </last-name>
          <first-name>
            <xsl:value-of select="normalize-space(substring-after(ap-tw-legal-name,','))"/>
          </first-name>
          <iid>
            <xsl:value-of select="ap-tw-legal-iid"/>
          </iid>
          <registered-number />
          <address lang="tw">
            <dtext />
          </address>
          <email />
        </addressbook>
      </legal-representative>
    </submitter>
  </xsl:template>

  <xsl:template match="simplesubmitter">
    <submitter>
      <xsl:attribute name="sequence">
        <xsl:number value="position()" format="1"/>
      </xsl:attribute>
      <xsl:attribute name="designated-receiver">
        <xsl:text>n</xsl:text>
      </xsl:attribute>
      <addressbook lang="tw">
        <xsl:choose>
          <xsl:when test="count(simpleap-tw-name)&gt;0">
            <last-name>
              <xsl:value-of select="normalize-space(substring-before(simpleap-tw-name,','))"/>
            </last-name>
            <first-name>
              <xsl:value-of select="normalize-space(substring-after(simpleap-tw-name,','))"/>
            </first-name>
          </xsl:when>
          <xsl:otherwise>
            <orgname>
              <xsl:value-of select="normalize-space(simpleap-tw-comname)"/>
            </orgname>
          </xsl:otherwise>
        </xsl:choose>
        <role/>
        <iid/>
        <registered-number />
        <representative />
        <address lang="tw">
          <zip-code/>
          <dtext />
        </address>
        <phones>
          <phone-region />
          <phone />
        </phones>
        <fax />
        <cell-phone />
        <email />
      </addressbook>
      <addressbook lang="en">
        <xsl:choose>
          <xsl:when test="count(simpleap-en-name)&gt;0">
            <last-name>
              <xsl:value-of select="normalize-space(substring-before(simpleap-en-name,','))"/>
            </last-name>
            <first-name>
              <xsl:value-of select="normalize-space(substring-after(simpleap-en-name,','))"/>
            </first-name>
          </xsl:when>
          <xsl:otherwise>
            <orgname>
              <xsl:value-of select="normalize-space(simpleap-en-comname)"/>
            </orgname>
          </xsl:otherwise>
        </xsl:choose>
        <iid/>
        <registered-number />
        <representative />
        <address lang="en">
          <dtext />
        </address>
        <email />
      </addressbook>
      <nationality>
        <country>
          <xsl:value-of select="substring(simpleap-country,'3')"/>
        </country>
        <country-code>
          <xsl:value-of select="substring(simpleap-country,'1','2')"/>
        </country-code>
      </nationality>
      <residence>
        <country />
      </residence>
      <legal-representative lang="tw">
        <addressbook lang="tw">
          <last-name />
          <first-name />
          <iid />
          <registered-number />
          <address lang="tw">
            <dtext />
          </address>
          <email />
        </addressbook>
      </legal-representative>
    </submitter>
  </xsl:template>

  <xsl:template match="correspondence-address">
    <correspondence-address>
      <addressbook lang="tw">
        <last-name>
          <xsl:value-of select="normalize-space(substring-before(co-tw-name,','))"/>
        </last-name>
        <first-name>
          <xsl:value-of select="normalize-space(substring-after(co-tw-name,','))"/>
        </first-name>
        <iid>
          <xsl:value-of select="co-tw-iid"/>
        </iid>
        <registered-number/>
        <address lang="tw">
          <zip-code>
            <xsl:value-of select="co-zip-code"/>
          </zip-code>
          <dtext>
            <xsl:value-of select="co-tw-address"/>
          </dtext>
        </address>
        <phones>
          <phone-region/>
          <phone>
            <xsl:value-of select="co-tw-phone"/>
          </phone>
        </phones>
        <email/>
      </addressbook>
    </correspondence-address>
  </xsl:template>

  <xsl:template match="agent">
    <agent agent-type="agent" rep-type="agent">
      <xsl:attribute name="sequence">
        <xsl:number value="position()" format="1"/>
      </xsl:attribute>
      <addressbook lang="tw">
        <last-name>
          <xsl:value-of select="normalize-space(substring-before(ag-tw-name,','))"/>
        </last-name>
        <first-name>
          <xsl:value-of select="normalize-space(substring-after(ag-tw-name,','))"/>
        </first-name>
        <iid>
          <xsl:value-of select="ag-tw-iid"/>
        </iid>
        <registered-number/>
        <address lang="tw">
          <zip-code>
            <xsl:value-of select="ag-zip-code"/>
          </zip-code>
          <dtext>
            <xsl:value-of select="ag-tw-address"/>
          </dtext>
        </address>
        <phones>
          <phone-region/>
          <phone>
            <xsl:value-of select="ag-tw-phone"/>
          </phone>
        </phones>
        <fax>
          <xsl:value-of select="ag-tw-fax"/>
        </fax>
        <cell-phone>
          <xsl:value-of select="ag-tw-cell-phone"/>
        </cell-phone>
        <email>
          <xsl:value-of select="ag-tw-email"/>
        </email>
      </addressbook>
      <customer-number>
        <xsl:value-of select="ag-customer-number"/>
      </customer-number>
    </agent>
  </xsl:template>

  <xsl:template match="simpleagent">
    <agent agent-type="agent" rep-type="agent">
      <xsl:attribute name="sequence">
        <xsl:number value="position()" format="1"/>
      </xsl:attribute>
      <addressbook lang="tw">
        <last-name>
          <xsl:value-of select="normalize-space(substring-before(simpleag-tw-name,','))"/>
        </last-name>
        <first-name>
          <xsl:value-of select="normalize-space(substring-after(simpleag-tw-name,','))"/>
        </first-name>
        <iid/>
        <registered-number/>
        <address lang="tw">
          <zip-code/>
          <dtext/>
        </address>
        <phones>
          <phone-region/>
          <phone/>
        </phones>
        <fax/>
        <cell-phone/>
        <email/>
      </addressbook>
      <customer-number/>
    </agent>
  </xsl:template>

  <xsl:template match="basis">
    <basis>
      <date>
        <xsl:value-of select="basis-date"/>
      </date>
      <basis1></basis1>
      <basis2>
        <xsl:value-of select="basis-basis2"/>
      </basis2>
      <basis-num>
        <xsl:value-of select="basis-num"/>
      </basis-num>
    </basis>
  </xsl:template>


  <xsl:attribute-set name="AddPageCount">
    <xsl:attribute name="add">y</xsl:attribute>
    <xsl:attribute name="page-count"/>
  </xsl:attribute-set>

  <xsl:attribute-set name="Add">
    <xsl:attribute name="add">y</xsl:attribute>
  </xsl:attribute-set>

  <xsl:attribute-set name="AddLang">
    <xsl:attribute name="add">y</xsl:attribute>
    <xsl:attribute name="lang"/>
  </xsl:attribute-set>

  <xsl:template match="opt-claim06">
    <opt-claim>
      <xsl:text>6</xsl:text>
    </opt-claim>
  </xsl:template>
  <xsl:template match="opt-claim07">
    <opt-claim>
      <xsl:text>7</xsl:text>
    </opt-claim>
    <opt-plus>
      <xsl:if test="string-length(../opt-claim07/claim07-amount-total) &gt;0">
        <xsl:text>1</xsl:text>
      </xsl:if>
      <xsl:if test="string-length(../opt-claim07/claim07-amount-refund) &gt;0">
        <xsl:text>0</xsl:text>
      </xsl:if>
    </opt-plus>
  </xsl:template>

  <xsl:template match="contact| 
				power-of-attorney| 
				citation-list| 
        third-reason| 
				citation-documents| 
				public-date| 
				foreign-translate">
    <xsl:copy use-attribute-sets="Add">
      <xsl:attribute name="list-seq">
        <xsl:value-of select="@list-seq"/>
      </xsl:attribute>
      <xsl:apply-templates select="*|node()"/>
    </xsl:copy>
  </xsl:template>

  <xsl:template match="check-list">
    <xsl:apply-templates select="contact[string-length(string())&gt;'0']"/>
    <xsl:apply-templates select="power-of-attorney[string-length(string())&gt;'0']"/>
    <xsl:apply-templates select="citation-list[string-length(string())&gt;'0']"/>
    <xsl:apply-templates select="third-reason[string-length(string())&gt;'0']"/>
    <xsl:apply-templates select="citation-documents[string-length(string())&gt;'0']"/>
    <xsl:apply-templates select="public-date[string-length(string())&gt;'0']"/>
    <xsl:apply-templates select="foreign-translate"/>
    <xsl:apply-templates select="cl-other-document[string-length(string())&gt;'0']"/>
  </xsl:template>

  <xsl:template match="cl-other-document">
    <cl-other-document>
      <xsl:attribute name="list-seq">
        <xsl:value-of select="@list-seq"/>
      </xsl:attribute>
      <doc-description>
        <xsl:value-of select="doc-description"/>
      </doc-description>
      <doc-filename>
        <xsl:value-of select="doc-filename"/>
      </doc-filename>
    </cl-other-document>
  </xsl:template>


  <xsl:template match="i">
    <i>
      <xsl:apply-templates select="*|text()"/>
    </i>
  </xsl:template>
  <xsl:template match="u">
    <u>
      <xsl:apply-templates select="*|text()"/>
    </u>
  </xsl:template>
  <xsl:template match="b">
    <b>
      <xsl:apply-templates select="*|text()"/>
    </b>
  </xsl:template>
  <xsl:template match="s">
    <s>
      <xsl:apply-templates select="*|text()"/>
    </s>
  </xsl:template>
  <xsl:template match="sup">
    <sup>
      <xsl:apply-templates select="*|text()"/>
    </sup>
  </xsl:template>
  <xsl:template match="sub">
    <sub>
      <xsl:apply-templates select="*|text()"/>
    </sub>
  </xsl:template>


</xsl:stylesheet>
